@@ -39,17 +39,16 @@
 
 #define FULLSCREEN_POPUP_TIMEOUT 5
 
-static void totem_fullscreen_class_init	(TotemFullscreenClass *class);
-static void totem_fullscreen_init (TotemFullscreen *parser);
 static void totem_fullscreen_dispose (GObject *object);
 static void totem_fullscreen_finalize (GObject *object);
 static gboolean totem_fullscreen_popup_hide (TotemFullscreen *fs);
 
 /* Callback functions for GtkBuilder */
-gboolean totem_fullscreen_vol_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
-gboolean totem_fullscreen_vol_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
-gboolean totem_fullscreen_seek_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
-gboolean totem_fullscreen_seek_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_vol_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_vol_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_seek_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_seek_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event, TotemFullscreen *fs);
 
 struct _TotemFullscreenPrivate {
 	BaconVideoWidget *bvw;
@@ -207,20 +206,10 @@ totem_fullscreen_set_cursor (TotemFullscreen *fs, gboolean state)
 		bacon_video_widget_set_show_cursor (fs->priv->bvw, state);
 }
 
-static GtkWidget *
-totem_fullscreen_get_volume_popup (TotemFullscreen *fs)
-{
-	return gtk_widget_get_toplevel (GTK_SCALE_BUTTON (fs->volume)->plus_button);
-}
-
 static gboolean
 totem_fullscreen_is_volume_popup_visible (TotemFullscreen *fs)
 {
-	GtkWidget *toplevel;
-
-	/* FIXME we should use the popup-visible property instead */
-	toplevel = totem_fullscreen_get_volume_popup (fs);
-	return GTK_WIDGET_VISIBLE (toplevel);
+	return GTK_WIDGET_VISIBLE (gtk_scale_button_get_popup (GTK_SCALE_BUTTON (fs->volume)));
 }
 
 static void
@@ -252,7 +241,7 @@ totem_fullscreen_popup_hide (TotemFullscreen *fs)
 	return FALSE;
 }
 
-gboolean
+G_MODULE_EXPORT gboolean
 totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event,
 				TotemFullscreen *fs)
 {
@@ -332,7 +321,7 @@ totem_fullscreen_parent_window_notify (GtkWidget *parent_window,
 	if (totem_fullscreen_is_fullscreen (fs) == FALSE)
 		return;
 
-	popup = totem_fullscreen_get_volume_popup (fs);
+	popup = gtk_scale_button_get_popup (GTK_SCALE_BUTTON (fs->volume));
 	if (parent_window == fs->priv->parent_window &&
 	    gtk_window_is_active (GTK_WINDOW (parent_window)) == FALSE &&
 	    GTK_WIDGET_VISIBLE (popup) == FALSE) {
